#
# spec file for package python-twine
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-twine
Version:        1.15.0
Release:        bp155.3.11
Summary:        Collection of utilities for interacting with PyPI
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/pypa/twine
Source:         https://files.pythonhosted.org/packages/source/t/twine/twine-%{version}.tar.gz
BuildRequires:  %{python_module pkginfo >= 1.4.2}
BuildRequires:  %{python_module pretend}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module readme_renderer >= 21.0}
BuildRequires:  %{python_module requests >= 2.17.0}
BuildRequires:  %{python_module requests-toolbelt >= 0.8.0}
BuildRequires:  %{python_module setuptools >= 0.7.0}
BuildRequires:  %{python_module tqdm >= 4.14}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pkginfo >= 1.4.2
Requires:       python-readme_renderer >= 21.0
Requires:       python-requests >= 2.17.0
Requires:       python-requests-toolbelt >= 0.8.0
Requires:       python-setuptools >= 0.7.0
Requires:       python-tqdm >= 4.14
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-keyring
%if %{with python2}
# tests/test_package.py will fail without pyblake2
BuildRequires:  python2-pyblake2
Recommends:     python-pyblake2
%endif
%python_subpackages

%description
Twine is a utility for publishing Python packages on PyPI.

Currently it supports registering projects, uploading distributions, and
checking, if descriptions will render correctly.

%prep
%setup -q -n twine-%{version}

sed -i '1s/^#!.*//' twine/__main__.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/twine
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative twine

%postun
%python_uninstall_alternative twine

%files %{python_files}
%doc AUTHORS README.rst
%license LICENSE
%dir %{python_sitelib}/twine
%dir %{python_sitelib}/twine-%{version}-py*.egg-info
%{python_sitelib}/twine/*
%{python_sitelib}/twine-%{version}-py*.egg-info/*
%python_alternative %{_bindir}/twine

%changelog
* Tue Nov 30 2021 Max Lin <mlin@suse.com>
- Disabled python2
* Tue Feb 16 2021 Yuchen Lin <mlin+factory@suse.de>
- Do not build the python2 package since python-readme_renderer 25.0
* Tue Feb 25 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.15.0
- last with python2
- Improved output on check command
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.14.0:
  * Better error handling and gpg2 fallback if gpg not available.
  * Fixes for python 3.8
* Sat Mar  2 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * be more specific in %%files section
  * remove patch fix-keyring-support.patch, included upstream
- update to version 1.13.0:
  * bug`452` Restore prompts while retaining support for suppressing
    prompts.
  * bug`447` Avoid requests-toolbelt to 0.9.0 to prevent attempting to
    use openssl when it isn't available.
  * :feature:`427` Add disable_progress_bar option to disable tqdm.
  * :feature:`426` Allow defining an empty username and password in
    .pypirc.
  * bug`441` Only install pyblake2 if needed.
  * bug`444` Use io.StringIO instead of StringIO.
  * bug`436` Use modern Python language features.
  * :support:`439` Refactor tox env and travis config.
  * bug`435` Specify python_requires in setup.py
  * bug`432` Use https URLs everywhere.
  * bug`428` Fix --skip-existing for Nexus Repos.
  * :feature:`419` Support keyring.get_credential.
  * :feature:`418` Support keyring.get_username_and_password.
  * bug`421` Remove unnecessary usage of readme_render.markdown.
  * :feature:" Add Python 3.7 to classifiers.
  * bug`412` Don't crash if there's no package description.
  * bug`408` Fix keyring support.
* Sat Feb  9 2019 Matej Cepl <mcepl@suse.com>
- Add fix-keyring-support.patch fixing
  gh#pypa/twine#408
* Sat Feb  9 2019 Matej Cepl <mcepl@suse.com>
- Deduplicate installed files
* Fri Jan  4 2019 Hans-Peter Jansen <hpj@urpla.net>
- update to version 1.12.1
  - bug`404` Fix regression with upload exit code
- update to version 1.12.0
  - feature`395 major` Add twine check command to check long description
  - feature`392 major` Drop support for Python 3.3
  - feature`363` Empower --skip-existing for Artifactory repositories
  - bug`367` Avoid MD5 when Python is compiled in FIPS mode
- Fix source URL
- add python-readme_renderer dependency
- BuildRequire python2-pyblake2 for successful testing
* Mon May 21 2018 tchvatal@suse.com
- Recommend the pyblake2 on python2 as it is included in py3.6+
  but was never in py2
* Mon May 21 2018 tchvatal@suse.com
- Switch to github archive to have test fixtures
- Enable tests
* Sat May 19 2018 hpj@urpla.net
- adjust requirements
* Fri May 18 2018 hpj@urpla.net
- update to version 1.11.0
  - see https://github.com/pypa/twine/blob/master/docs/changelog.rst
* Thu May 17 2018 tchvatal@suse.com
- Format with spec-cleaner and reduce the license conditions
* Thu Jul  6 2017 sebix+novell.com@sebix.at
- fix source url
* Wed Jul  5 2017 sebix+novell.com@sebix.at
- update to version 1.9.1
- update specfile to singlespec
* Wed Jan 18 2017 michael@stroeder.com
- Update to version 1.8.1
- requires python-requests-toolbelt>=0.4.0
* Fri Sep 25 2015 p.drouand@gmail.com
- Update to version 1.6.1
  * bug:`130` Fix signing support for uploads
- Implement update-alternatives
* Wed Jul 16 2014 toddrme2178@gmail.com
- BuildRequires: python-setuptools
- Add executable
* Tue Feb  4 2014 speilicke@suse.com
- Initial version
